@@ -122,6 +122,11 @@ public class JUnitRunnerTestCase {
         TestReport report = test.run();
         if (!report.hasPassed()) {
             System.out.println("Failed: " + id);
+            if (report.getDescription() != null) {
+                for (TestReport.Entry entry : report.getDescription()) {
+                    System.out.println(entry.getKey() + " " + entry.getValue());
+                }
+            }
         }
         Assert.assertTrue(id, report.hasPassed());
     }
@@ -129,24 +134,24 @@ public class JUnitRunnerTestCase {
     private static List<String> EXCLUDE = Arrays.asList(
 //fail on CI
 "ATransform.defaultContextGeneration",
-"BasicShapes.defaultContextGeneration",
-"BasicShapes2.defaultContextGeneration",
-"BStroke.defaultContextGeneration",
 "Bug4945.defaultContextGeneration",
 "Bug6535.defaultContextGeneration",
 "Bug17965.defaultContextGeneration",
 "Color1.defaultContextGeneration",
-"Color1.renderingCheck",
 "Color2.defaultContextGeneration",
 "Gradient.defaultContextGeneration",
 "IdentityTest.defaultContextGeneration",
-"Lookup.renderingCheck",
 "NegativeLengths.defaultContextGeneration",
-"Rescale.renderingCheck",
 "ShearTest.defaultContextGeneration",
 "TextSpacePreserve.defaultContextGeneration",
-"TextSpacePreserve.renderingCheck",
+"BasicShapes.defaultContextGeneration",
 "TransformCollapse.defaultContextGeneration",
+"BasicShapes2.defaultContextGeneration",
+"BStroke.defaultContextGeneration",
+"Color1.renderingCheck",
+"Lookup.renderingCheck",
+"Rescale.renderingCheck",
+"TextSpacePreserve.renderingCheck",
 "NullSetSVGDocumentTest",
 "samples/tests/spec/scripting/memoryLeak1.svg",
 "samples/tests/spec/scripting/primaryDoc.svg",
@@ -572,35 +577,8 @@ public class JUnitRunnerTestCase {
 "TransformCollapse.configuredContextGeneration",
 "TransformCollapse.renderingCheck",
 "TransformCollapse.ContextrenderingCheck",
-"ConfigErrorTest.ERROR_UNABLE_TO_CREATE_OUTPUT_DIR",
 "defaultTest",
 "org.apache.batik.util.ApplicationSecurityEnforcerTest$CheckNoPolicyFile",
-"B64.1",
-"B64.2",
-"B64.3",
-"B64.4",
-"B64.5",
-"B64.6",
-"B64.7",
-"B64.8",
-"B64.9",
-"B64.10",
-"B64.11",
-"B64.12",
-"B64.13",
-"B64.14",
-"B64.15",
-"B64.16",
-"B64.17",
-"B64.18",
-"B64.19",
-"B64.20",
-"B64.21",
-"B64.22",
-"B64.23",
-"B64.24",
-"B64.25",
-"B64.26",
 "ecmaCheckPermissionsDenied",
 "ecmaCheckPermissionsDeniedFunction",
 "ecmaCheckPermissionsDeniedEval",
@@ -611,64 +589,6 @@ public class JUnitRunnerTestCase {
 "jarCheckLoadSameAsDocument(scripts=application/java-archive)(scriptOrigin=document)(secure=true)",
 "jarCheckLoadSameAsDocument(scripts=application/java-archive)(scriptOrigin=document)(secure=false)",
 "jarCheckPermissionsGranted",
-"externalResourcesAccess.unsecure",
-"bridge/error/rect-negative-width",
-"bridge/error/clipPath-clipPathUnits-invalid",
-"bridge/error/clipPath-subelement-invalid",
-"bridge/error/clipPath-uri-illegal",
-"bridge/error/ellipse-missing-rx",
-"bridge/error/ellipse-missing-ry",
-"bridge/error/ellipse-negative-rx",
-"bridge/error/ellipse-negative-ry",
-"bridge/error/feColorMatrix-type-invalid",
-"bridge/error/feColorMatrix-value-invalid",
-"bridge/error/feColorMatrix-values-invalid",
-"bridge/error/feComponentTransfert-type-invalid",
-"bridge/error/feComponentTransfert-type-missing",
-"bridge/error/feComponentTransfert-value-invalid",
-"bridge/error/feComposite-in2-missing",
-"bridge/error/feComposite-operator-invalid",
-"bridge/error/feDisplacementMap-channelSelector-invalid",
-"bridge/error/feDisplacementMap-in2-missing",
-"bridge/error/feGaussianBlur-stdDeviationX-invalid",
-"bridge/error/feGaussianBlur-stdDeviationY-invalid",
-"bridge/error/feMerge-feMergeNode-invalid",
-"bridge/error/feMorphology-operator-invalid",
-"bridge/error/feMorphology-radiusX-negative",
-"bridge/error/feMorphology-radiusY-negative",
-"bridge/error/feTurbulence-stitchTiles.invalid",
-"bridge/error/feTurbulence-type-invalid",
-"bridge/error/filter-filterPrimitive-invalid",
-"bridge/error/filter-filterResX-negative",
-"bridge/error/filter-filterResY-negative",
-"bridge/error/filter-filterUnits-invalid",
-"bridge/error/filter-uri-illegal",
-"bridge/error/image-missing-height",
-"bridge/error/image-missing-width",
-"bridge/error/image-negative-height",
-"bridge/error/image-negative-width",
-"bridge/error/linearGradient-gradientUnits-invalid",
-"bridge/error/linearGradient-missing-offset",
-"bridge/error/linearGradient-spreadMethod-invalid",
-"bridge/error/linearGradient-uri-invalid",
-"bridge/error/mask-maskUnits-invalid",
-"bridge/error/mask-subelement-invalid",
-"bridge/error/mask-uri-illegal",
-"bridge/error/path-invalid-d",
-"bridge/error/pattern-patternUnits-invalid",
-"bridge/error/pattern-subelement-invalid",
-"bridge/error/polygon-invalid-points",
-"bridge/error/polyline-invalid-points",
-"bridge/error/radialGradient-gradientUnits-invalid",
-"bridge/error/radialGradient-missing-offset",
-"bridge/error/radialGradient-r-negative",
-"bridge/error/radialGradient-spreadMethod-invalid",
-"bridge/error/rect-missing-height",
-"bridge/error/rect-missing-width",
-"bridge/error/rect-negative-height",
-"bridge/error/rect-negative-rx",
-"bridge/error/rect-negative-ry",
-"bridge/error/transform",
 // exclude additional failures appearing under JDK 1.8.0_152 on MacOS
 "Bug4389.renderingCheck",
 "Bug4389.ContextrenderingCheck",
