@@ -64,7 +64,7 @@ import org.apache.batik.test.TestReport;
  * all pixel values are the same).
  *
  * @author <a href="mailto:vhardy@apache.lorg">Vincent Hardy</a>
- * @version $Id: AbstractRenderingAccuracyTest.java 1808888 2017-09-19 14:22:11Z ssteiner $
+ * @version $Id: AbstractRenderingAccuracyTest.java 1904401 2022-10-04 12:54:33Z ssteiner $
  */
 public abstract class AbstractRenderingAccuracyTest extends AbstractTest {
     /**
@@ -424,6 +424,7 @@ public abstract class AbstractRenderingAccuracyTest extends AbstractTest {
         FileOutputStream tmpFileOS = null;
 
         try{
+            tmpFile.getParentFile().mkdirs();
             tmpFileOS = new FileOutputStream(tmpFile);
         }catch(IOException e){
             report.setErrorCode(ERROR_CANNOT_CREATE_TEMP_FILE_STREAM);
@@ -649,6 +650,7 @@ public abstract class AbstractRenderingAccuracyTest extends AbstractTest {
     protected void saveImage(BufferedImage img, File imgFile)
         throws IOException {
         if(!imgFile.exists()){
+            imgFile.getParentFile().mkdirs();
             imgFile.createNewFile();
         }
         OutputStream out = new FileOutputStream(imgFile);
