@@ -52,6 +52,7 @@ import org.apache.batik.bridge.RelaxedScriptSecurity;
 import org.apache.batik.bridge.ScriptSecurity;
 import org.apache.batik.bridge.UserAgentAdapter;
 import org.apache.batik.test.AbstractTest;
+import org.apache.batik.test.DefaultTestReport;
 import org.apache.batik.test.TestReport;
 import org.apache.batik.util.ApplicationSecurityEnforcer;
 import org.apache.batik.util.ParsedURL;
@@ -82,7 +83,7 @@ import org.w3c.dom.Element;
  * - Validate (e.g., "true")
  *
  * @author <a href="mailto:vhardy@apache.org">Vincent Hardy</a>
- * @version $Id: SVGOnLoadExceptionTest.java 1831626 2018-05-15 11:10:36Z ssteiner $
+ * @version $Id: SVGOnLoadExceptionTest.java 1904389 2022-10-04 09:24:20Z ssteiner $
  */
 public class SVGOnLoadExceptionTest extends AbstractTest {
     /**
@@ -337,7 +338,13 @@ public class SVGOnLoadExceptionTest extends AbstractTest {
                                               "org/apache/batik/apps/svgbrowser/resources/svgbrowser.policy");
 
         if (secure) {
-            ase.enforceSecurity(true);
+            try {
+                ase.enforceSecurity(true);
+            } catch (UnsupportedOperationException e) {
+                if ("java.lang.SecurityException".equals(expectedExceptionClass)) {
+                    return new DefaultTestReport(this);
+                }
+            }
         }
 
         try {
